==> ugene_1.7.1+repack.orig.tar.gz: ugene-1.7.1/src/plugins_3rdparty/hmm2/src/u_search/HMMSearchWorker.h <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_HMMSEARCH_WORKER_H_
#define _GB2_HMMSEARCH_WORKER_H_

#include <workflow_library/LocalDomain.h>
#include <workflow_support/WorkflowUtils.h>

#include "uhmmsearch.h"

namespace GB2 {

namespace LocalWorkflow {

class HMMSearchPrompter : public PrompterBase<HMMSearchPrompter> {
    Q_OBJECT
public:
    HMMSearchPrompter(Actor* p = 0) : PrompterBase<HMMSearchPrompter>(p) {}
protected:
    QString composeRichDoc();
};

class HMMSearchWorker : public BaseWorker {
    Q_OBJECT
public:
    HMMSearchWorker(Actor* a);
    virtual void init();
    virtual bool isReady();
    virtual Task* tick();
    virtual bool isDone();
    virtual void cleanup();
    
private slots:
    void sl_taskFinished(Task*);

protected:
    IntegralBus *hmmPort, *seqPort, *output;
    QString resultName;
    UHMMSearchSettings cfg;
    QList<plan7_s*> hmms;
    
}; 

class HMMSearchWorkerFactory : public DomainFactory {
public:
    static const QString ACTOR;
    static void init();
    HMMSearchWorkerFactory() : DomainFactory(ACTOR) {}
    virtual Worker* createWorker(Actor* a) {return new HMMSearchWorker(a);}
};

}//Workflow namespace
}//GB2 namespace

#endif

==> ugene_1.9.1+repack.orig.tar.gz: ugene-1.9.1/src/plugins_3rdparty/hmm2/src/u_search/HMMSearchWorker.h <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _U2_HMMSEARCH_WORKER_H_
#define _U2_HMMSEARCH_WORKER_H_

#include <U2Lang/LocalDomain.h>
#include <U2Lang/WorkflowUtils.h>

#include "uhmmsearch.h"

namespace U2 {

namespace LocalWorkflow {

class HMMSearchPrompter : public PrompterBase<HMMSearchPrompter> {
    Q_OBJECT
public:
    HMMSearchPrompter(Actor* p = 0) : PrompterBase<HMMSearchPrompter>(p) {}
protected:
    QString composeRichDoc();
};

class HMMSearchWorker : public BaseWorker {
    Q_OBJECT
public:
    HMMSearchWorker(Actor* a);
    virtual void init();
    virtual bool isReady();
    virtual Task* tick();
    virtual bool isDone();
    virtual void cleanup();
    
private slots:
    void sl_taskFinished(Task*);

protected:
    IntegralBus *hmmPort, *seqPort, *output;
    QString resultName;
    UHMMSearchSettings cfg;
    QList<plan7_s*> hmms;
    
}; 

class HMMSearchWorkerFactory : public DomainFactory {
public:
    static const QString ACTOR;
    static void init();
    HMMSearchWorkerFactory() : DomainFactory(ACTOR) {}
    virtual Worker* createWorker(Actor* a) {return new HMMSearchWorker(a);}
};

} // Workflow namespace
} // U2 namespace

#endif
